@@ -7,7 +7,22 @@
 #' @seealso [stats::Exponential]
 #'
 #' @examples
-#' dist_exponential(rate = c(2, 1, 2/3))
+#' dist <- dist_exponential(rate = c(2, 1, 2/3))
+#'
+#' dist
+#' mean(dist)
+#' variance(dist)
+#' skewness(dist)
+#' kurtosis(dist)
+#'
+#' generate(dist, 10)
+#'
+#' density(dist, 2)
+#' density(dist, 2, log = TRUE)
+#'
+#' cdf(dist, 4)
+#'
+#' quantile(dist, 0.7)
 #'
 #' @name dist_exponential
 #' @export
@@ -37,6 +52,11 @@ density.dist_exponential <- function(x, at, ...){
   stats::dexp(at, x[["rate"]])
 }
 
+#' @export
+log_density.dist_exponential <- function(x, at, ...){
+  stats::dexp(at, x[["rate"]], log = TRUE)
+}
+
 #' @export
 quantile.dist_exponential <- function(x, p, ...){
   stats::qexp(p, x[["rate"]])
@@ -61,3 +81,9 @@ mean.dist_exponential <- function(x, ...){
 variance.dist_exponential <- function(x, ...){
   1/x[["rate"]]^2
 }
+
+#' @export
+skewness.dist_exponential <- function(x, ...) 2
+
+#' @export
+kurtosis.dist_exponential <- function(x, ...) 6
